@@ -5,8 +5,8 @@ use hudsucker::{
     openssl::{hash::MessageDigest, pkey::PKey, x509::X509},
     *,
 };
-use log::*;
 use std::net::SocketAddr;
+use tracing::*;
 
 async fn shutdown_signal() {
     tokio::signal::ctrl_c()
@@ -36,7 +36,7 @@ impl HttpHandler for LogHandler {
 
 #[tokio::main]
 async fn main() {
-    env_logger::init();
+    tracing_subscriber::fmt::init();
 
     let private_key_bytes: &[u8] = include_bytes!("ca/hudsucker.key");
     let ca_cert_bytes: &[u8] = include_bytes!("ca/hudsucker.pem");
